@@ -7,7 +7,7 @@ use Carp ();
 use Ref::Util qw( is_ref is_plain_arrayref is_plain_hashref );
 
 # ABSTRACT: C data types for FFI
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 
 our %ffi;
@@ -97,6 +97,45 @@ sub array
 }
 
 
+sub enum
+{
+  (undef)    = shift;
+  my $name   = defined $_[0] && !is_ref $_[0] ? shift : undef;
+  my @values = defined $_[0] && is_plain_arrayref $_[0] ? @{shift()} : ();
+  my %config = defined $_[0] && is_plain_hashref $_[0]  ? %{shift()} : ();
+
+  my($class, $filename) = caller;
+
+  unless(defined $name)
+  {
+    $name = lcfirst [split /::/, $class]->[-1];
+    $name =~ s/([A-Z]+)/'_' . lc($1)/ge;
+    $name .= "_t";
+  }
+
+  my $ffi = _ffi_get($filename),
+
+  $config{package} ||= $class;
+  my @maps;
+  $config{maps} = \@maps;
+  my $rev = $config{rev}  ||= 'str';
+
+  $ffi->load_custom_type('::Enum', $name, \%config, @values);
+
+  my($str_lookup, $int_lookup, $type) = @maps;
+
+  require FFI::C::Def;
+  $ffi->def('FFI::C::EnumDef', $name,
+    FFI::C::EnumDef->new(
+      str_lookup => $str_lookup,
+      int_lookup => $int_lookup,
+      type       => $type,
+      rev        => $rev,
+    )
+  );
+}
+
+
 1;
 
 __END__
@@ -111,7 +150,7 @@ FFI::C - C data types for FFI
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -275,6 +314,17 @@ generated.  For an array you give it the member type and the element count.
 The element count is optional for variable length arrays, but keep in mind
 that when you create such an array you do need to provide a size.
 
+=head2 enum
+
+ FFI::C->enum($name, \@values, \%config);
+ FFI::C->enum(\@values, \%config);
+ FFI::C->enum(\@values, \%config);
+ FFI::C->enum(\@values);
+
+Defines an enum.  The C<@values> and C<%config> are passed to
+L<FFI::Platypus::Type::Enum>, except the constants are exported
+to the calling package by default.
+
 =head1 EXAMPLES
 
 =head2 unix time struct
